/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.it;

import java.util.List;
import java.util.Vector;

import org.apache.log4j.Logger;
import org.ogf.graap.wsag.client.api.AgreementFactoryClient;

/**
 * AbstractAgreementFactoryPersistenceTest
 * 
 * @author Oliver Waeldrich
 * 
 */
public abstract class AbstractAgreementFactoryPersistenceTest extends AbstractIntegrationTest
{

    @SuppressWarnings( "unused" )
    private static final Logger LOG = Logger.getLogger( AbstractAgreementFactoryPersistenceTest.class );

    /**
     * 
     * @param name
     *            the test name
     */
    public AbstractAgreementFactoryPersistenceTest( String name )
    {
        super( name );
    }

    /**
     * Check that all configured factory are deployed in the same order as specified in configuration file.
     */
    public void testDeployedFactories()
    {
        try
        {
            AgreementFactoryClient[] factories = getAgreementFactoryClients();
            assertEquals( getDefaultFactoryCount(), factories.length );

            // build a list of resource ids
            List<String> resourceIds = new Vector<String>();

            for ( int i = 0; i < factories.length; i++ )
            {
                resourceIds.add( factories[i].getResourceId() );
            }

            checkDeployedFactories( resourceIds );
        }
        catch ( Exception ex )
        {
            fail( "Test failed with message: " + ex.getMessage() );
        }

    }

    /**
     * Checks the resource id's of the deployed factories. Concrete implementations may overwrite this method
     * when more than one factory is deployed in order to check all expected factory id's.
     * 
     * @param resourceIds
     *            the resource id's of the deployed factories
     */
    protected void checkDeployedFactories( List<String> resourceIds )
    {
        assertTrue( resourceIds.contains( "SAMPLE-INSTANCE-1" ) );
    }

}
