/* 
 * Copyright (c) 2007, Fraunhofer-Gesellschaft
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are
 * met:
 * 
 * (1) Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the disclaimer at the end.
 *     Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in
 *     the documentation and/or other materials provided with the
 *     distribution.
 * 
 * (2) Neither the name of Fraunhofer nor the names of its
 *     contributors may be used to endorse or promote products derived
 *     from this software without specific prior written permission.
 * 
 * DISCLAIMER
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 * "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 * A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 * OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 * LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 * OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *  
 */
package org.ogf.graap.wsag.it;

import java.util.GregorianCalendar;

import org.apache.log4j.Logger;
import org.ogf.graap.wsag.api.exceptions.NegotiationFactoryException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnavailableException;
import org.ogf.graap.wsag.api.exceptions.ResourceUnknownException;
import org.ogf.graap.wsag.client.api.AgreementFactoryClient;
import org.ogf.graap.wsag.client.api.NegotiationClient;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationContextDocument;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationContextType;
import org.ogf.schemas.graap.wsAgreement.negotiation.NegotiationRoleType;

/**
 * Default unit test implementation for the negotiation factory.
 * 
 * @author hrasheed
 * 
 */
public abstract class AbstractNegotiationFactoryTest extends AbstractIntegrationTest
{

    private static final Logger LOG = Logger.getLogger( AbstractNegotiationFactoryTest.class );

    private static final String FACTORY_RESOURCE_ID = "SAMPLE-INSTANCE-1";

    /**
     * 
     * @param name
     *            the test name
     */
    public AbstractNegotiationFactoryTest( String name )
    {
        super( name );
    }

    /**
     * Tests the proper initiation of a negotiation process.
     * 
     * @throws Exception
     *             indicates a test failure
     */
    public void testInitiateNegotiation() throws Exception
    {

        try
        {

            AgreementFactoryClient[] factories = getAgreementFactoryClients();
            assertEquals( getDefaultFactoryCount(), factories.length );

            AgreementFactoryClient factory = null;

            if ( factories[0].getResourceId().equals( FACTORY_RESOURCE_ID ) )
            {
                factory = getAgreementFactoryClients()[0];
            }
            else
            {
                factory = getAgreementFactoryClients()[1];
            }

            NegotiationContextDocument contextDoc = NegotiationContextDocument.Factory.newInstance();
            NegotiationContextType context = contextDoc.addNewNegotiationContext();
            context.addNewNegotiationType().addNewNegotiation();
            context.setAgreementResponder( NegotiationRoleType.NEGOTIATION_INITIATOR );
            context.setExpirationTime( new GregorianCalendar() );

            NegotiationClient negotiation = factory.initiateNegotiation( context );
            assertNotNull( "the created negotiatin client is not null", negotiation );
            LOG.info( "negotiation instance is created successfully" );
        }
        catch ( NegotiationFactoryException e )
        {
            fail( "NegotiationFactoryException: " + e.getMessage() );
        }
        catch ( ResourceUnavailableException e )
        {
            fail( "ResourceUnavailableException: " + e.getMessage() );
        }
        catch ( ResourceUnknownException e )
        {
            fail( "ResourceUnknownException: " + e.getMessage() );
        }
        catch ( Exception e )
        {
            fail( "Could not create negotiation client instance. Error: " + e.getMessage() );
        }
    }
}
